@@ -1,13 +1,13 @@
 setAs("dgTMatrix", "dgCMatrix",
-      function(from) .Call("dgTMatrix_to_dgCMatrix", from, PACKAGE = "Matrix")
+      function(from) .Call(dgTMatrix_to_dgCMatrix, from)
       )
 
 setAs("dgTMatrix", "dgeMatrix",
-      function(from) .Call("dgTMatrix_to_dgeMatrix", from, PACKAGE = "Matrix")
+      function(from) .Call(dgTMatrix_to_dgeMatrix, from)
       )
 
 setAs("dgTMatrix", "matrix",
-      function(from) .Call("dgTMatrix_to_matrix", from, PACKAGE = "Matrix")
+      function(from) .Call(dgTMatrix_to_matrix, from)
       )
 
 setAs("dgeMatrix", "dgTMatrix",
@@ -151,19 +151,19 @@ setReplaceMethod("[", signature(x = "dgTMatrix", i = "index", j = "index",
 
 setMethod("crossprod", signature(x = "dgTMatrix", y = "missing"),
           function(x, y = NULL)
-          .Call("csc_crossprod", as(x, "dgCMatrix"), PACKAGE = "Matrix"))
+          .Call(csc_crossprod, as(x, "dgCMatrix")))
 
 setMethod("crossprod", signature(x = "dgTMatrix", y = "matrix"),
           function(x, y = NULL)
-          .Call("csc_matrix_crossprod", as(x, "dgCMatrix"), y, PACKAGE = "Matrix"))
+          .Call(csc_matrix_crossprod, as(x, "dgCMatrix"), y))
 
 ##setMethod("crossprod", signature(x = "dgTMatrix", y = "numeric"),
 ##          function(x, y = NULL)
-##          .Call("csc_matrix_crossprod", as(x, "dgCMatrix"), as.matrix(y), PACKAGE = "Matrix"))
+##          .Call(csc_matrix_crossprod, as(x, "dgCMatrix"), as.matrix(y)))
 
 setMethod("tcrossprod", signature(x = "dgTMatrix", y = "missing"),
           function(x, y = NULL)
-          .Call("csc_tcrossprod", as(x, "dgCMatrix"), PACKAGE = "Matrix"))
+          .Call(csc_tcrossprod, as(x, "dgCMatrix")))
 
 setMethod("image", "dgTMatrix",
           function(x,
@@ -237,8 +237,27 @@ setMethod("kronecker", signature(X = "dgTMatrix", Y = "dgTMatrix"),
 
 setMethod("writeHB", signature(obj = "dgTMatrix"),
           function(obj, file, ...)
-          .Call("Matrix_writeHarwellBoeing", obj, as.character(file), "DGT", PACKAGE = "Matrix"))
+          .Call(Matrix_writeHarwellBoeing, obj, as.character(file), "DGT"))
 
 setMethod("writeMM", signature(obj = "dgTMatrix"),
           function(obj, file, ...)
-          .Call("Matrix_writeMatrixMarket", obj, as.character(file), "DGT", PACKAGE = "Matrix"))
+          .Call(Matrix_writeMatrixMarket, obj, as.character(file), "DGT"))
+
+
+setMethod("colSums", signature(x = "dgTMatrix"),
+	  function(x, na.rm = FALSE, dims = 1)
+          tapply1(x@x, factor(x@j, 0:(x@Dim[2]-1)), sum, na.rm = na.rm),
+	  valueClass = "numeric")
+setMethod("colMeans", signature(x = "dgTMatrix"),
+	  function(x, na.rm = FALSE, dims = 1)
+          tapply1(x@x, factor(x@j, 0:(x@Dim[2]-1)), mean, na.rm = na.rm),
+	  valueClass = "numeric")
+
+setMethod("rowSums", signature(x = "dgTMatrix"),
+	  function(x, na.rm = FALSE, dims = 1)
+          tapply1(x@x, factor(x@i, 0:(x@Dim[1]-1)), sum, na.rm = na.rm),
+	  valueClass = "numeric")
+setMethod("rowMeans", signature(x = "dgTMatrix"),
+	  function(x, na.rm = FALSE, dims = 1)
+          tapply1(x@x, factor(x@i, 0:(x@Dim[1]-1)), mean, na.rm = na.rm),
+	  valueClass = "numeric")
