@@ -9,11 +9,11 @@ setAs("dgCMatrix", "dsCMatrix",
 
 setAs("dsCMatrix", "dsTMatrix",
       function(from) ## Cholmod:
-      .Call("Csparse_to_Tsparse", from, PACKAGE = "Matrix"))
+      .Call(Csparse_to_Tsparse, from))
 
 setAs("dsCMatrix", "dgTMatrix", # needed for image()
       function(from) ## pre-Cholmod:
-      .Call("dsCMatrix_to_dgTMatrix", from, PACKAGE = "Matrix"))
+      .Call(dsCMatrix_to_dgTMatrix, from))
 
 setAs("dsCMatrix", "dgeMatrix",
       function(from) as(as(from, "dgTMatrix"), "dgeMatrix"))
@@ -30,13 +30,13 @@ setAs("dsCMatrix", "lsCMatrix",
                          Dim = from@Dim, Dimnames = from@Dimnames))
 
 setAs("dsCMatrix", "dgCMatrix",
-      function(from) .Call("sCMatrix_to_gCMatrix", from, PACKAGE = "Matrix"))
+      function(from) .Call(sCMatrix_to_gCMatrix, from))
 
 if(FALSE) # have 'C' version above
 setAs("dsCMatrix", "dsTMatrix",
       function(from)
       new("dsTMatrix", i = from@i,
-          j = .Call("Matrix_expand_pointers", from@p, PACKAGE = "Matrix"),
+          j = .Call(Matrix_expand_pointers, from@p),
           x = from@x, uplo = from@uplo,
           Dim= from@Dim, Dimnames = from@Dimnames)
       )
@@ -46,12 +46,12 @@ setAs("dsCMatrix", "dsyMatrix",
 
 setMethod("solve", signature(a = "dsCMatrix", b = "dgeMatrix"),
           function(a, b, ...)
-          .Call("dsCMatrix_matrix_solve", a, b, TRUE, PACKAGE = "Matrix"),
+          .Call(dsCMatrix_matrix_solve, a, b, TRUE),
           valueClass = "dgeMatrix")
 
 setMethod("solve", signature(a = "dsCMatrix", b = "matrix"),
           function(a, b, ...)
-          .Call("dsCMatrix_matrix_solve", a, b, FALSE, PACKAGE = "Matrix"),
+          .Call(dsCMatrix_matrix_solve, a, b, FALSE),
           valueClass = "dgeMatrix")
 
 ##setMethod("solve", signature(a = "dsCMatrix", b = "numeric"),
@@ -59,13 +59,13 @@ setMethod("solve", signature(a = "dsCMatrix", b = "matrix"),
 ##          valueClass = "dgeMatrix")
 
 setMethod("chol", signature(x = "dsCMatrix", pivot = "missing"),
-          function(x, pivot, LINPACK) .Call("dsCMatrix_chol", x, TRUE, PACKAGE = "Matrix"))
+          function(x, pivot, LINPACK) .Call(dsCMatrix_chol, x, TRUE))
 
 setMethod("chol", signature(x = "dsCMatrix", pivot = "logical"),
-          function(x, pivot, LINPACK) .Call("dsCMatrix_chol", x, pivot, PACKAGE = "Matrix"))
+          function(x, pivot, LINPACK) .Call(dsCMatrix_chol, x, pivot))
 
 setMethod("t", signature(x = "dsCMatrix"),
-          function(x) .Call("ssc_transpose", x, PACKAGE = "Matrix"),
+          function(x) .Call(ssc_transpose, x),
           valueClass = "dsCMatrix")
 
 setMethod("determinant", signature(x = "dsCMatrix", logarithm = "missing"),
@@ -84,12 +84,12 @@ setMethod("determinant", signature(x = "dsCMatrix", logarithm = "logical"),
 
 setMethod("writeHB", signature(obj = "dsCMatrix"),
           function(obj, file, ...)
-          .Call("Matrix_writeHarwellBoeing",
+          .Call(Matrix_writeHarwellBoeing,
                 if (obj@uplo == "U") t(obj) else obj,
-                as.character(file), "DSC", PACKAGE = "Matrix"))
+                as.character(file), "DSC"))
 
 setMethod("writeMM", signature(obj = "dsCMatrix"),
           function(obj, file, ...)
-          .Call("Matrix_writeMatrixMarket",
+          .Call(Matrix_writeMatrixMarket,
                 if (obj@uplo == "U") t(obj) else obj,
-                as.character(file), "DSC", PACKAGE = "Matrix"))
+                as.character(file), "DSC"))
