@@ -4,6 +4,13 @@
 ##   to stabilize the variance parameters at the beginning a Laplace
 ##   fit.
 
+## To Do: Determine why the names of the components of the values of
+##   the ranef and coef extractor methods are not printed.
+
+## To Do: Change the output format for lmer objects to always print
+##   the values of the log-likelihood and the
+##   restricted-log-likelihood.  Base AIC and BIC on the log-likelihood.
+
 ## Some utilities
 
 ## Return the pairs of expressions separated by vertical bars
@@ -293,6 +300,9 @@ setMethod("lmer", signature(formula = "formula"),
 				       list(fac = x[[3]])), mf))
 	  ## order factor list by decreasing number of levels
 	  nlev <- sapply(fl, function(x) length(levels(x)))
+	  if(any(nlev == 0))
+	      stop("resulting factor(s) with 0 levels in random effects part:\n ",
+		   names(nlev[nlev == 0]))
 	  if (any(diff(nlev) > 0)) {
 	      ord <- rev(order(nlev))
 	      bars <- bars[ord]
@@ -310,8 +320,7 @@ setMethod("lmer", signature(formula = "formula"),
 			   X, Y, method, sapply(Ztl, nrow),
 			   c(lapply(Ztl, rownames), list(.fixed = colnames(X))),
 			   !(family$family %in% c("binomial", "poisson")),
-			   match.call(), family,
-			   PACKAGE = "Matrix")
+			   match.call(), family)
 	      .Call(mer_ECMEsteps, mer, cv$niterEM, cv$EMverbose)
 	      LMEoptimize(mer) <- cv
 	      return(new("lmer", mer,
@@ -354,9 +363,9 @@ setMethod("lmer", signature(formula = "formula"),
 	  if (method == "PQL") {
 	      .Call(glmer_devLaplace, PQLpars, GSpt)
 	      .Call(glmer_finalize, GSpt)
-	      return(new("lmer", mer,
+	      return(new("glmer", mer,
 			 frame = if (model) mf else data.frame(),
-			 terms = mt))
+			 terms = mt, weights = weights))
 	  }
 
 	  fixInd <- seq(ncol(X))
@@ -375,9 +384,10 @@ setMethod("lmer", signature(formula = "formula"),
 		     control = list(trace = cv$msVerbose,
 		     iter.max = cv$msMaxIter))
 	  .Call(glmer_finalize, GSpt)
-	  return(new("lmer", mer,
+	  return(new("glmer", mer,
 		     frame = if (model) mf else data.frame(),
-		     terms = mt))
+		     terms = mt,
+                     weights = weights))
 
       })
 
@@ -484,58 +494,87 @@ setMethod("qqmath", signature(x = "ranef.lmer"),
           })
 
 setMethod("deviance", signature(object = "mer"),
-	  function(object, ...) {
+	  function(object, REML = NULL, ...) {
+              if (is.null(REML)) REML <- object@method == "REML"
 	      .Call(mer_factor, object)
-	      object@deviance[[ifelse(object@method == "REML", "REML", "ML")]]
+	      object@deviance[[ifelse(REML, "REML", "ML")]]
 	  })
 
-setMethod("mcmcsamp", signature(object = "mer"),
+## Mangle the names of the columns of the mcmcsamp result ans
+## This operation is common to the methods for "lmer" and "glmer"
+mcmccompnames <- function(ans, object, saveb, trans, glmer)
+{
+    gnms <- names(object@flist)
+    cnms <- object@cnames
+    ff <- fixef(object)
+    colnms <- c(names(ff), if (glmer) character(0) else "sigma^2",
+                unlist(lapply(seq(along = gnms),
+                              function(i)
+                              abbrvNms(gnms[i],cnms[[i]]))))
+    if (trans) {
+        ## parameter type: 0 => fixed effect, 1 => variance,
+        ##		 2 => covariance
+        ptyp <- c(integer(length(ff)), if (glmer) integer(0) else 1:1,
+                  unlist(lapply(seq(along = gnms),
+                                function(i)
+                            {
+                                k <- length(cnms[[i]])
+                                rep(1:2, c(k, (k*(k-1))/2))
+                            })))
+        colnms[ptyp == 1] <-
+            paste("log(", colnms[ptyp == 1], ")", sep = "")
+        colnms[ptyp == 2] <-
+            paste("atanh(", colnms[ptyp == 2], ")", sep = "")
+    }
+    colnms <- c(colnms, "deviance")
+    if(saveb) {## maybe better colnames, "RE.1","RE.2", ... ?
+        rZy <- object@rZy
+        colnms <- c(colnms,
+                    paste("b", sprintf(paste("%0",
+                                             1+floor(log(length(rZy),10)),
+                                             "d", sep = ''),
+                                       seq(along = rZy)),
+                          sep = '.'))
+    }
+    colnames(ans) <- colnms
+    ans
+}
+                          
+setMethod("mcmcsamp", signature(object = "lmer"),
 	  function(object, n = 1, verbose = FALSE, saveb = FALSE,
 		   trans = TRUE, ...)
       {
-	  family <- object@family
-	  lmm <- family$family == "gaussian" && family$link == "identity"
-	  if (!lmm)
-	      stop("mcmcsamp for GLMMs not yet implemented in supernodal representation")
-	  ans <- t(.Call(mer_MCMCsamp, object, saveb, n,
-			 trans))
+          ans <- t(.Call(mer_MCMCsamp, object, saveb, n, trans))
 	  attr(ans, "mcpar") <- as.integer(c(1, n, 1))
 	  class(ans) <- "mcmc"
-	  glmer <- FALSE
-	  gnms <- names(object@flist)
-	  cnms <- object@cnames
-	  ff <- fixef(object)
-	  colnms <- c(names(ff), if (glmer) character(0) else "sigma^2",
-		      unlist(lapply(seq(along = gnms),
-				    function(i)
-				    abbrvNms(gnms[i],cnms[[i]]))))
-	  if (trans) {
-	      ## parameter type: 0 => fixed effect, 1 => variance,
-	      ##		 2 => covariance
-	      ptyp <- c(integer(length(ff)), if (glmer) integer(0) else 1:1,
-			unlist(lapply(seq(along = gnms),
-				      function(i)
-				  {
-				      k <- length(cnms[[i]])
-				      rep(1:2, c(k, (k*(k-1))/2))
-				  })))
-	      colnms[ptyp == 1] <-
-		  paste("log(", colnms[ptyp == 1], ")", sep = "")
-	      colnms[ptyp == 2] <-
-		  paste("atanh(", colnms[ptyp == 2], ")", sep = "")
-	  }
-	  colnms <- c(colnms, "deviance")
-	  if(saveb) {## maybe better colnames, "RE.1","RE.2", ... ?
-              rZy <- object@rZy
-	      colnms <- c(colnms,
-                          paste("b", sprintf(paste("%0",
-                                                   1+floor(log(length(rZy),10)),
-                                                      "d", sep = ''),
-                                             seq(along = rZy)),
-                                sep = '.'))
-          }
-          colnames(ans) <- colnms
-	  ans
+          mcmccompnames(ans, object, saveb, trans, FALSE)
+      })
+
+setMethod("mcmcsamp", signature(object = "glmer"),
+	  function(object, n = 1, verbose = FALSE, saveb = FALSE,
+		   trans = TRUE, ...)
+      {
+          family <- object@family
+          mer <- as(object, "mer")
+          weights <- object@weights
+          cv <- lmerControl()
+          eta <- .Call(mer_fitted, mer)
+          offset <- numeric(length(eta)) ## change this, save the offset in mer
+          Y <- object@y
+          wtssqr <- weights * weights
+          linkinv <- quote(family$linkinv(eta))
+          mu.eta <- quote(family$mu.eta(eta))
+          mu <- family$linkinv(eta)
+          variance <- quote(family$variance(mu))
+          dev.resids <- quote(family$dev.resids(Y, mu, wtssqr))
+          LMEopt <- get("LMEoptimize<-")
+          doLMEopt <- quote(LMEopt(x = mer, value = cv))
+          GSpt <- .Call(glmer_init, environment())
+          ans <- t(.Call(glmer_MCMCsamp, GSpt, saveb, n, trans))
+          .Call(glmer_finalize, GSpt)
+	  attr(ans, "mcpar") <- as.integer(c(1, n, 1))
+	  class(ans) <- "mcmc"
+          mcmccompnames(ans, object, saveb, trans, TRUE)
       })
 
 setMethod("simulate", signature(object = "mer"),
@@ -666,7 +705,7 @@ setMethod("show", "mer",
 	      if (!is.null(so@call$formula))
 		  cat("Formula:", deparse(so@call$formula),"\n")
 	      if (!is.null(so@call$data))
-		  cat("	  Data:", deparse(so@call$data), "\n")
+		  cat("Data:", deparse(so@call$data), "\n")
 	      if (!is.null(so@call$subset))
 		  cat(" Subset:",
 		      deparse(asOneSidedFormula(so@call$subset)[[2]]),"\n")
