@@ -29,3 +29,6 @@ setMethod("!", "lsparseMatrix",
           ## turns FALSE to TRUE --> dense matrix
           function(e1) !as(e1, "lgeMatrix"))
 
+setMethod("diag", signature(x = "lsparseMatrix"),
+	  function(x, nrow, ncol = n) diag(as(x, "lgCMatrix")))
+
