@@ -1,6 +1,7 @@
 #include "Mutils.h"
 #include "HBMM.h"
 #include "chm_common.h"
+#include "CHMfactor.h"
 #include "Csparse.h"
 #include "Tsparse.h"
 #include "dense.h"
@@ -33,6 +34,7 @@
 static R_CallMethodDef CallEntries[] = {
     {"BunchKaufman_validate", (DL_FUNC) &BunchKaufman_validate, 1},
     {"pBunchKaufman_validate", (DL_FUNC) &pBunchKaufman_validate, 1},
+    {"CHMfactor_to_sparse", (DL_FUNC) &CHMfactor_to_sparse, 1},
     {"Cholesky_validate", (DL_FUNC) &Cholesky_validate, 1},
     {"Csparse_Csparse_prod", (DL_FUNC) &Csparse_Csparse_prod, 2},
     {"Csparse_band", (DL_FUNC) &Csparse_band, 3},
@@ -163,7 +165,7 @@ static R_CallMethodDef CallEntries[] = {
     {"dtrMatrix_rcond", (DL_FUNC) &dtrMatrix_rcond, 2},
     {"dtrMatrix_solve", (DL_FUNC) &dtrMatrix_solve, 1},
     {"dtrMatrix_validate", (DL_FUNC) &dtrMatrix_validate, 1},
-/*     {"glmer_MCMCsamp", (DL_FUNC) &glmer_MCMCsamp, 6}, */
+    {"glmer_MCMCsamp", (DL_FUNC) &glmer_MCMCsamp, 4},
     {"glmer_PQL", (DL_FUNC) &glmer_PQL, 1},
 /*     {"glmer_devAGQ", (DL_FUNC) &glmer_devAGQ, 3}, */
     {"glmer_devLaplace", (DL_FUNC) &glmer_devLaplace, 2},
@@ -178,6 +180,7 @@ static R_CallMethodDef CallEntries[] = {
     {"lCholCMatrix_validate", (DL_FUNC) &lCholCMatrix_validate, 1},
     {"lcsc_to_matrix", (DL_FUNC) &lcsc_to_matrix, 1},
     {"lgCMatrix_crossprod", (DL_FUNC) &lgCMatrix_crossprod, 3},
+    {"lgCMatrix_diag", (DL_FUNC) &lgCMatrix_diag, 1},
     {"lgCMatrix_lgCMatrix_mm", (DL_FUNC) &lgCMatrix_lgCMatrix_mm, 2},
     {"lgCMatrix_picky_column", (DL_FUNC) &lgCMatrix_picky_column, 1},
     {"lgCMatrix_trans", (DL_FUNC) &lgCMatrix_trans, 1},
