@@ -345,6 +345,7 @@ int mm_write_mtx_crd(char fname[], int M, int N, int nz, int I[], int J[],
 {
     FILE *f;
     int i;
+    char *tmp;
 
     if (strcmp(fname, "stdout") == 0) 
         f = stdout;
@@ -354,7 +355,9 @@ int mm_write_mtx_crd(char fname[], int M, int N, int nz, int I[], int J[],
     
     /* print banner followed by typecode */
     fprintf(f, "%s ", MatrixMarketBanner);
-    fprintf(f, "%s\n", mm_typecode_to_str(matcode));
+    tmp = mm_typecode_to_str(matcode);
+    fprintf(f, "%s\n", tmp);
+    if (tmp) free(tmp);
 
     /* print matrix sizes and nonzeros */
     fprintf(f, "%d %d %d\n", M, N, nz);
